>From c5cefc3580e3c53cb5eead211de1716764c2ac15 Mon Sep 17 00:00:00 2001
From: Joerg Albert <jal2@gmx.de>
Date: Sun, 1 May 2016 12:34:59 +0000
Subject: [PATCH 1/2] edi.c: added more error and debug output

---
 edi.c |   16 +++++++++++++---
 1 file changed, 13 insertions(+), 3 deletions(-)

diff --git a/edi.c b/edi.c
index 4ffb46a..85e5178 100644
--- a/edi.c
+++ b/edi.c
@@ -68,8 +68,10 @@ static int edi_read_byte(struct flashctx *flash, unsigned short address, unsigne
 	edi_read_cmd(cmd, address);
 
 	rc = spi_send_command(flash, sizeof(cmd), sizeof(buffer), cmd, buffer);
-	if (rc)
+	if (rc) {
+		msg_perr("EDI: %s: spi_send_command failed with %d\n", __func__, rc);
 		return -1;
+	}
 
 	idx = 0;
 
@@ -149,13 +151,21 @@ static int edi_chip_probe(struct flashctx *flash, const struct ene_chip *chip)
 	unsigned char ediid;
 	int rc;
 
+	msg_pdbg("probing for EDI\n");
+
 	rc = edi_read(flash, ENE_EC_HWVERSION, &hwversion);
-	if (rc < 0)
+	if (rc < 0) {
+		msg_perr("EDI: failed to read hw version (%d)\n", rc);
 		return 0;
+	}
 
 	rc = edi_read(flash, ENE_EC_EDIID, &ediid);
-	if (rc < 0)
+	if (rc < 0) {
+		msg_perr("EDI: failed to read EDI id (%d)\n", rc);
 		return 0;
+	}
+
+	msg_pdbg("EDI: found hw version 0x%02x EDI id 0x%02x\n", hwversion, ediid);
 
 	if (chip->hwversion == hwversion && chip->ediid == ediid)
 		return 1;
-- 
1.7.10.4

